@@ -23,6 +23,10 @@
 
 namespace Mercator {
 
+inline unsigned int BasePoint::seed() const
+{
+    return I_ROUND(m_height * 1000.0);
+}
 
 /// \brief Helper to interpolate on a line.
 ///
@@ -32,23 +36,24 @@ namespace Mercator {
 class LinInterp {
   private:
     /// The length of the line.
-    int m_size;
+    float m_size;
     /// Flag indicating that both points have the same value.
     bool noCalc;
   public:
     /// Values at the two ends.
     float ep1, ep2;
     /// \brief Determine the interpolated value along the line.
-    inline float calc(int loc) 
+    inline float calc(float loc) 
     {
-        return ((noCalc) ? ep1 : ((m_size-loc) * ep1 + loc * ep2));
+        return ((noCalc) ? ep1 :
+                ((m_size-loc) * ep1 + loc * ep2));
     }
     /// \brief Constructor
     ///
     /// @param size length of the line.
     /// @param l value at one end of the line.
     /// @param h value at one end of the line.
-    LinInterp(int size,float l, float h) : m_size(size), noCalc(false), 
+    LinInterp(float size,float l, float h) : m_size(size), noCalc(false), 
               ep1(l/size), ep2(h/size) 
     {
         if (l==h) {
@@ -67,18 +72,18 @@ class LinInterp {
 class QuadInterp {
   private:
     /// The length of one side of the square quad.
-    int m_size;
+    float m_size;
     /// Flag indicating that all points have the same value.
     bool noCalc;
   public:
     /// Values at the four corners.
     float ep1, ep2, ep3, ep4;
     /// \brief Determine the interpolated value within the quad.
-    inline float calc(int locX, int locY) 
+    inline float calc(float locX, float locY) 
     {
         return  ((noCalc) ? ep1 :
-                (( ep1*(m_size-locX) + ep2 * locX) * (m_size-locY) +
-                ( ep4*(m_size-locX) + ep3 * locX) * (locY) ) / m_size );
+                 (( ep1*(m_size-locX) + ep2 * locX) * (m_size-locY) +
+                 ( ep4*(m_size-locX) + ep3 * locX) * (locY) ) / m_size );
     }
     /// \brief Constructor
     ///
@@ -87,7 +92,7 @@ class QuadInterp {
     /// @param e2 value at one corner of the square quad.
     /// @param e3 value at one corner of the square quad.
     /// @param e4 value at one corner of the square quad.
-    QuadInterp(int size,float e1, float e2, float e3, float e4)
+    QuadInterp(float size,float e1, float e2, float e3, float e4)
         : m_size(size), noCalc(false),
           ep1(e1/size), ep2(e2/size), ep3(e3/size), ep4(e4/size) 
     {
@@ -298,19 +303,19 @@ void Segment::populateSurfaces()
 inline float randHalf(WFMath::MTRand& rng)
 {
     //return (float) rand() / RAND_MAX - 0.5f;
-    return rng() - 0.5;
+    return rng.rand<float>() - 0.5f;
 }
 
 
 /// \brief quasi-Random Midpoint Displacement (qRMD) algorithm.
 float Segment::qRMD(WFMath::MTRand& rng, float nn, float fn, float ff, float nf,
-                    float roughness, float falloff, int depth) const
+                    float roughness, float falloff, float depth) const
 {
     float max = std::max(std::max(nn, fn), std::max(nf, ff)),
           min = std::min(std::min(nn, fn), std::min(nf, ff)),
           heightDifference = max - min;
  
-    return ((nn+fn+ff+nf)/4.f) + randHalf(rng) * roughness * heightDifference / (1.f+::pow(depth,falloff));
+    return ((nn+fn+ff+nf)/4.f) + randHalf(rng) * roughness * heightDifference / (1.f+std::pow(depth,falloff));
 }
 
 /// \brief Check a value against m_min and m_max and set one of them
@@ -356,13 +361,13 @@ void Segment::fill1d(const BasePoint& l, const BasePoint &h,
 
     // depth is used to indicate what level we are on. the displacement is
     // reduced each time we traverse the array.
-    int depth=1;
+    float depth=1;
  
     while (stride) {
         for (int i=stride;i<m_res;i+=stride*2) {
             float hh = array[i-stride];
             float lh = array[i+stride];
-            float hd = F_ABS(hh-lh);
+            float hd = std::fabs(hh-lh);
             float roughness = li.calc(i);
 
             //eliminate the problem where hd is nearly zero, leaving a flat section.
@@ -370,7 +375,7 @@ void Segment::fill1d(const BasePoint& l, const BasePoint &h,
                 hd+=0.05f * roughness;       
             }
           
-            array[i] = ((hh+lh)/2.f) + randHalf(rng) * roughness  * hd / (1.f+::pow(depth,BasePoint::FALLOFF));
+            array[i] = ((hh+lh)/2.f) + randHalf(rng) * roughness  * hd / (1.f+std::pow(depth,BasePoint::FALLOFF));
         }
         stride >>= 1;
         depth++;
@@ -435,7 +440,7 @@ void Segment::fill2d(const BasePoint& p1, const BasePoint& p2,
     QuadInterp qi(m_res, p1.roughness(), p2.roughness(), p3.roughness(), p4.roughness());
 
     float f = BasePoint::FALLOFF;
-    int depth=0;
+    float depth=0;
     
     // center of m_points is done separately
     int stride = m_res/2;
@@ -531,8 +536,8 @@ void Segment::getHeightAndNormal(float x, float y, float& h,
     assert(y >= 0.0f);
     
     // get index of the actual tile in the segment
-    int tile_x = (int)floor(x);
-    int tile_y = (int)floor(y);
+    int tile_x = I_ROUND(std::floor(x));
+    int tile_y = I_ROUND(std::floor(y));
 
     // work out the offset into that tile
     float off_x = x - tile_x;
