@@ -5,10 +5,13 @@
 #ifndef MERCATOR_IROUND_H
 #define MERCATOR_IROUND_H
 
-#ifndef PACKAGE
+#ifndef PACKAGE_NAME
 #error iround.h must be included after config.h
 #endif
 
+// FIXME tr1 contains std::tr1::lrint which is type overloaded
+// In c++0x this becomes std::lrint
+
 #ifdef HAVE_LRINTF
     #define I_ROUND(_x) (::lrintf(_x)) 
 #elif defined(HAVE_RINTF)
@@ -19,10 +22,4 @@
     #define I_ROUND(_x) ((int)(_x)) 
 #endif
 
-#ifdef HAVE_FABSF
-    #define F_ABS(_x) (::fabsf(_x))
-#else
-    #define F_ABS(_x) (::fabs(_x))
-#endif
-
 #endif // MERCATOR_IROUND_H
